Learn R Programming

AssayCorrector (version 2.0.0)

detect_bias: Detect the type of bias present in the assay

Description

detect (1) identifies rows and columns of all plates of the assay affected by spatial bias (following the results of the Mann-Whitney U test); (2) identifies well locations (i.e., well positions scanned across all plates of a given assay) affected by spatial bias (also following the results of the Mann-Whitney U test).

Usage

detect_bias(assay, alpha = 0.01, type = "P", test = "AD")

Arguments

assay

The assay to be corrected. Has to be an assay object.

alpha

Significance level threshold (defaults to 0.01)

type

P:plate-specific, A:assay-specific, PA:plate then assay-specific, AP:assay then plate-specific

test

KS:Kolmogorov-Smirnov (1933), AD:Anderson-Darling (1952), CVM:Cramer-von-Mises (1928)

Value

The corrected assay (assay object)

Examples

Run this code
# NOT RUN {
assay<-create_assay(m)
detected<-detect_bias(assay)
# }

Run the code above in your browser using DataLab