detect_bias: Detect the type of bias present in the assay
Description
detect (1) identifies rows and columns of all plates of the assay affected by spatial bias (following the results of the Mann-Whitney U test); (2) identifies well locations (i.e., well positions scanned across all plates of a given assay) affected by spatial bias (also following the results of the Mann-Whitney U test).
Usage
detect_bias(assay, alpha = 0.01, type = "P", test = "AD")
Arguments
assay
The assay to be corrected. Has to be an assay object.
alpha
Significance level threshold (defaults to 0.01)
type
P:plate-specific, A:assay-specific, PA:plate then assay-specific, AP:assay then plate-specific